@@ -11,6 +11,7 @@ from jupyter_server.utils import url_path_join
 from datetime import datetime
 
 JWT_PATH = '/yq/jwt.txt'
+MINIO_PATH = '/yq/minio.json'
 JWT_HEADER = os.getenv('JWT_HEADER', default='userid-token')
 
 
@@ -94,6 +95,20 @@ class YqMinioIntegration(APIHandler):
                     try:
                         response = await http_client.fetch(f"http://localhost:8888{os.environ['NB_PREFIX']}/jupyterlab_s3_browser/auth?_xsrf={token}",
                                                            method="POST", headers=headers, body=data)
+                        with open(MINIO_PATH, 'w') as out:
+                            out.write(data)
+                            out.close()
+
+                        aws_creds = f'''
+[default]
+aws_access_key_id = {credentials["AccessKeyId"]}
+aws_secret_access_key = {credentials["SecretAccessKey"]}
+aws_session_token = {credentials["SessionToken"]}
+                        '''
+                        aws_creds_file = os.path.expanduser('~/.aws/credentials')
+                        with open(aws_creds_file, 'w') as out:
+                            out.write(aws_creds)
+                            out.close()
                     except httpclient.HTTPError as e:
                         # HTTPError is raised for non-200 responses; the response
                         # can be found in e.response.
